==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/capabilities/users/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.capabilities.users', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.capabilities.users', {
				url: '/{capName}/users',
				views: {
					capabilitiesContent: {
						templateUrl: 'common/modules/table/capabilityUsers/table.capabilityUsers.tpl.html',
						controller: 'TableCapabilityUsersController',
						resolve: {
							capability: function($stateParams, capabilityService) {
								return capabilityService.getCapability($stateParams.capName);
							},
							capUsers: function($stateParams, userService) {
								return userService.getUsers({ capability: $stateParams.capName });
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_portal/app/src/modules/private/capabilities/users/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.capabilities.users', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.capabilities.users', {
				url: '/{capName}/users',
				views: {
					capabilitiesContent: {
						templateUrl: 'common/modules/table/capabilityUsers/table.capabilityUsers.tpl.html',
						controller: 'TableCapabilityUsersController',
						resolve: {
							capability: function($stateParams, capabilityService) {
								return capabilityService.getCapabilities({"name": $stateParams.capName});
							},
							capUsers: function($stateParams, userService) {
								return userService.getUsers({ capability: $stateParams.capName });
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
